@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -443,8 +443,8 @@ sub gen_cli_doc_data_from_meta {
                 }
                 $cmdline = "[[prog]]";
                 for my $arg (@$argv) {
-                    $arg = String::ShellQuote::shell_quote($arg);
-                    $cmdline .= " $arg"; # XXX markup with color?
+                    my $qarg = String::ShellQuote::shell_quote($arg);
+                    $cmdline .= " $qarg"; # XXX markup with color?
                 }
             }
             my $egdata = {
@@ -479,7 +479,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.22 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-09-04.
+This document describes version 0.23 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-09-23.
 
 =head1 SYNOPSIS
 
@@ -534,7 +534,7 @@ Sample result:
            cmdline      => "[[prog]] 'a value' --bool1",
            description  => undef,
            example_spec => {
-                             argv    => ["'a value'", "--bool1"],
+                             argv    => ["a value", "--bool1"],
                              summary => "Summary for an example",
                              test    => 0,
                            },
